# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as BaseProvider


class Provider(BaseProvider):
    """
    Source: http://planet-beruf.de/schuelerinnen/mein-beruf/berufe-von-a-z/
    """
    jobs = [
        'Altenpfleger',
        'Asphaltbauer',
        'Artist',
        'Augenoptiker',
        'Ausbaufacharbeiter',
        'Bäcker',
        'Bankkaufmann',
        'Beamter',
        'Binnenschiffer',
        'Chemikant',
        'Chirurgiemechaniker',
        'Designer',
        'Drogist',
        'Erzieher',
        'Elektroniker',
        'Fachinformatiker',
        'Fleischer',
        'Florist',
        'Forstwirst',
        'Friseur',
        'Informatiker',
        'Programmierer',
        'Techniker',
        'Mathematiker',
        'Koreanistiker',
        'Mechaniker',
        'Pfleger',
        'Polizist',
        'Pilot',
        'Arzt',
        'Krankenschwester',
        'Medizininformatiker',
        'Schornsteinfeger',
        'Winzer',
    ]
