# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as BaseProvider


class Provider(BaseProvider):
    jobs = [
        'Αγγειοπλάστης',
        'Αγιογράφος Βυζαντινών Εικόνων και Τοιχογραφιών',
        'Αγρονόμος Τοπογράφος Μηχανικός',
        'Αγρότης Καλλιεργητής',
        'Αεροναυπηγός Μηχανικός',
        'Αεροσυνοδός',
        'Αθλητικός Δημοσιογράφος – Ρεπόρτερ',
        'Αισθητικός - Ειδικός Εφαρμογών Αισθητικής',
        'Αισθητικός Αρωματοθεραπείας',
        'Αισθητικός Επαγγελματικού Μακιγιάζ Θεάτρου και Σκηνής',
        'Αισθητικός Ποδολογίας και Καλλωπισμού Νυχιών',
        'Τεχνίτης Περιποίησης Νυχιών',
        'Ακροβάτης',
        'Ακτινοδιαγνώστης',
        'Αλουμινάς',
        'Αναισθησιολόγος',
        'Αναλογιστής',
        'Ανθοκόμος',
        'Αξιωματικός Μηχανικός Ναυσιπλοΐας',
        'Αξιωματικός Νοσηλευτικής',
        'Αξιωματικός Πολεμικής Αεροπορίας',
        'Αξιωματικός Στρατού Ξηράς',
        'Αξιωματικός Σωμάτων Ενόπλων Δυνάμεων',
        'Αξιωματικός Φαρμακοποιός',
        'Αργυροχρυσοχόος',
        'Αρτοποιός',
        'Αρχαιολόγος',
        'Αρχειοθέτης',
        'Αρχιμάγειρας',
        'Αρχισυντάκτης',
        'Αρχιτέκτονας',
        'Αστυνομικός',
        'Ασφαλιστής',
        'Βιβλιοδέτης',
        'Βιβλιοθηκονόμος',
        'Βιολόγος',
        'Βιοπληροφορικός',
        'Βοηθός Αναισθησιολόγου',
        'Βοηθός Αρτοποιίας – Ζαχαροπλαστικής',
        'Βοηθός Ιατρικών και Βιολογικών Εργαστηρίων, Βιοχημικού και Μικροβιολογικού Εργαστηρίου',
        'Βοηθός Ιατρικών και Βιολογικών Εργαστηρίων, Αιματολογικού Εργαστηρίου',
        'Βοηθός Κομμωτή',
        'Βοηθός Λογιστή',
        'Βοηθός Μαγειρικής Τέχνης',
        'Βοηθός Νοσηλευτή Μονάδας Εντατικής Θεραπείας',
        'Βοηθός Νοσηλευτή Τραυματολογίας',
        'Βοηθός Νοσηλευτή Χειρουργείου',
        'Βοηθός Οδοντιάτρου',
        'Βοηθός Φαρμακοποιού',
        'Βοηθός Φυσικοθεραπευτή σε Ιαματικές Πηγές και Λουτρά',
        'Βοηθός Φυσικοθεραπευτή - Υπάλληλος Εργαστηρίου Φυσικοθεραπείας',
        'Βοτανολόγος',
        'Βρεφοκόμος',
        'Γεωγράφος',
        'Γεωλόγος',
        'Γεωπόνος Φυτικής Παραγωγής',
        'Γεωργός Βιολογικής Γεωργίας',
        'Γεωτεχνολόγος',
        'Γεωτρυπανιστής',
        'Γεωφυσικός',
        'Γλωσσολόγος',
        'Γλύπτης',
        'Γουνοποιός',
        'Γραμματέας',
        'Γραμματέας Νομικών Επαγγελμάτων',
        'Γραφίστας',
        'Γραφολόγος',
        'Δάσκαλος',
        'Δασολόγος',
        'Δασοφύλακας - Ειδικός Δασικής Προστασίας',
        'Δημοσιογράφος Συντάκτης - Ρεπόρτερ Δημοσιογραφίας',
        'Διαδικτυακός Διαφημιστής',
        'Διαιτητής Αθλήματος',
        'Διαιτολόγος - Ειδικός Εφαρμογών Διαιτητικής',
        'Διακοσμητής - Τεχνικός Διακόσμησης',
        'Διαφημιστής',
        'Διαχειριστής Logistics',
        'Διαχειριστής Τεχνολογίας Internet',
        'Διερμηνέας',
        'Διευθυντής Eπιχειρήσεων',
        'Διευθύνων Επιχειρηματίας',
        'Δικαστής',
        'Δικαστικός Επιμελητής',
        'Δικηγόρος',
        'Διοικητικό Στέλεχος Αθλητισμού',
        'Διοικητικό και Οικονομικό Στέλεχος Επιχειρήσεων',
        'Διοικητικός Υπάλληλος',
        'Διπλωμάτης',
        'Εγκληματολόγος',
        'Εθνολόγος - Λαογράφος',
        'Ειδικός 3D Animation',
        'Ειδικός Αεροπορικών Εταιριών',
        'Ειδικός Αργυροχρυσοχοΐας',
        'Ειδικός Ασφαλιστικών Εργασιών',
        'Ειδικός Γεωγραφικών Πληροφοριακών Συστημάτων',
        'Ειδικός Διοίκησης Πολιτισμικών Μονάδων',
        'Ειδικός Εκπαίδευσης Ενηλίκων',
        'Ειδικός Εμπορίας, Διαφήμισης και Προώθησης Προϊόντων',
        'Ειδικός Εμπορικών Επιχειρήσεων',
        'Ειδικός Ενδυματολογίας και Σχεδίασης Μόδας',
        'Ειδικός Επιστήμων Θάλασσας',
        'Ειδικός Ηλεκτρονικής Σχεδίασης Εντύπου',
        'Ειδικός Ιατρικών Συσκευών Ακτινοθεραπείας',
        'Ειδικός Ιατρικών Συσκευών Απεικονίσεων',
        'Ειδικός Ιατρικών και Βιολογικών Εργαστηρίων Αιματολογικού Εργαστηρίου',
        'Ειδικός Κινηματογράφου',
        'Ειδικός Μάρκετινγκ',
        'Ειδικός Μουσικής με Τεχνολογία Η/Υ',
        'Ειδικός Ναυτιλιακής Κατεύθυνσης',
        'Ειδικός Νοσηλευτικής Ατόμων με Ψυχικές Παθήσεις',
        'Ειδικός Νοσηλευτικής Μονάδων Εντατικής Θεραπείας',
        'Ειδικός Νοσηλευτικής Ογκολογικών Παθήσεων',
        'Ειδικός Νοσηλευτικής Τραυματολογίας',
        'Ειδικός Ξενοδοχειακής Ψυχαγωγίας',
        'Ειδικός Ξενοδοχειακών Υπηρεσιών και Τροφοδοσίας',
        'Ειδικός Οδοντοτεχνικής Ορθοδοντικής',
        'Ειδικός Οδοντοτεχνικής Πορσελάνης',
        'Ειδικός Οπτικών και Ηχητικών Εφέ',
        'Ειδικός Παθολόγος Λόγου και Ομιλίας',
        'Ειδικός Πληροφοριακών Συστημάτων με Πολυμέσα',
        'Ειδικός Προσχολικής Αγωγής Δραστηριοτήτων Δημιουργίας και Έκφρασης',
        'Ειδικός Προσχολικής Αγωγής Ημερήσιας Φροντίδας Παιδιών με Ειδικές Ανάγκες',
        'Ειδικός Πρόληψης και Θεραπείας Εξαρτημένων Ατόμων',
        'Ειδικός Πωλήσεων',
        'Ειδικός Στατιστικής Έρευνας Αγοράς και Δημοσκοπήσεων – Στέλεχος Στατιστικής Δημοσκόπησης',
        'Ειδικός Συναρμολόγησης Εικόνας (Μοντέρ) - Ηλεκτρονική Επεξεργασία Εικόνας',
        'Ειδικός Σχεδίασης Διαδραστικών και Βιομηχανικών Προϊόντων και Συστημάτων',
        'Ειδικός Σχεδίου και Μάρκετινγκ Μόδας',
        'Ειδικός Σχεδιασμού Αστικής και Περιφερειακής Ανάπτυξης',
        'Ειδικός Σχεδιασμού Επίπλου',
        'Ειδικός Τροφοδοσίας-Σίτισης',
        'Υδροθεραπευτής - Λουτροθεραπευτής',
        'Ειδικός Φοροτεχνικού Γραφείου',
        'Ειδικός Φρουρός',
        'Ειδικός Ψηφιακών Μορφών Τέχνης',
        'Εικονογράφος - Σκιτσογράφος',
        'Εικονολήπτης',
        'Εισαγγελέας',
        'Εκδότης Βιβλίων',
        'Εκκλησιαστική και Πολιτιστική Κατάρτιση',
        'Εκπαιδευτής Ζώων',
        'Εκπαιδευτής Υποψήφιων Οδηγών Αυτοκινήτων και Μοτοσικλετών',
        'Εκπαιδευτικός Ειδικής Αγωγής',
        'Εκτελωνιστής και Πράκτορας Μεταφορών',
        'Εκτιμητής Έργων Τέχνης',
        'Εκτιμητής και Εκπλειστηριαστής',
        'Εκφωνητής',
        'Ελαιοχρωματιστής',
        'Ελεγκτής Εναέριας Κυκλοφορίας',
        'Ελεγκτής Ολικής Ποιότητας',
        'Ενδυματολόγος',
        'Επαγγελματίας Αθλητής',
        'Επαγγελματίας Δύτης',
        'Επαγγελματικό Μακιγιάζ',
        'Επιθεωρητής κτιρίων και πυρασφάλειας',
        'Επικοινωνιολόγος',
        'Επιμελητής Πτήσεων',
        'Επιπλοποιός',
        'Επισκέπτης Υγείας',
        'Επισκευαστής Λαμαρινών Αυτοκινήτων-Οχημάτων',
        'Επισκευαστής Πλαστικών Σκαφών',
        'Επιστήμων Πληροφορικής και Η/Υ',
        'Επόπτης Δημόσιας Υγείας',
        'Εργοθεραπευτής',
        'Ζαχαροπλάστης',
        'Ζωγράφος',
        'Ζωολόγος',
        'Ηθοποιός',
        'Ηλεκτρολόγος',
        'Ηλεκτρολόγος Μηχανικός και Μηχανικός Η/Υ',
        'Ηλεκτρονικός',
        'Ηχολήπτης',
        'Θεατρολόγος',
        'Θεολόγος-Ιεροκήρυκας',
        'Ιατρικός Επισκέπτης',
        'Ιατροδικαστής',
        'Ιατρός',
        'Ιερέας',
        'Ιεροψάλτης',
        'Ιστορικός',
        'Ιστορικός Τέχνης',
        'Ιχθυοκαλλιεργητής',
        'Ιχθυοπαθολόγος',
        'Καθηγητής Γυμναστικής',
        'Καθηγητής Δευτεροβάθμιας Εκπαίδευσης',
        'Καθηγητής Πρωτοβάθμιας Εκπαίδευσης',
        'Καθηγητής Τριτοβάθμιας Εκπαίδευσης',
        'Καλλιτέχνης',
        'Καμαριέρης - Καμαριέρα',
        'Κασκαντέρ',
        'Κατασκευαστής Ειδών Ενδυμασίας',
        'Κατασκευαστής Υποδημάτων',
        'Κεραμίστας',
        'Κηπουρός - Ανθοκηπουρός - Κηποτεχνικός',
        'Κλειδαράς',
        'Κλιματολόγος',
        'Κλωστοϋφαντουργός',
        'Κλόουν - Γελοτοποιός',
        'Κοινωνικός Ανθρωπολόγος',
        'Κοινωνικός Λειτουργός',
        'Κοινωνιολόγος',
        'Κομμωτής – Τεχνικός Περιποίησης Κόμης',
        'Κορνιζοποιός',
        'Κοσμετολόγος',
        'Κρεοπώλης',
        'Κριτικός Τέχνης',
        'Κτηματομεσίτης',
        'Μεσίτης Αστικών Συμβάσεων',
        'Διαχειριστής Ακίνητης Περιουσίας',
        'Κτηνίατρος',
        'Κτηνοτρόφος',
        'Κόπτης Ενδυμάτων',
        'Κόφτης Υποδημάτων',
        'Λατόμος',
        'Λιθογράφος Ψηφιακής Τεχνολογίας',
        'Λιμενεργάτης',
        'Λιμενικός',
        'Λογιστής - Ειδικός Μηχανογραφημένου Λογιστηρίου',
        'Λογοθεραπευτής',
        'Λογοτέχνης',
        'Μαθηματικός',
        'Μαιευτής – Μαία',
        'Μακιγιέρ/Μακιγιέζ',
        'Μαρμαράς',
        'Μελισσοκόμος',
        'Μεσίτης Ναυτιλιακών Συμβάσεων',
        'Μεταφραστής',
        'Μετεωρολόγος',
        'Μηχανικός Αεροσκαφών',
        'Μηχανικός Αυτοκινήτων',
        'Μηχανικός Διαχείρισης Ενεργειακών Πόρων',
        'Μηχανικός Εμπορικού Ναυτικού',
        'Μηχανικός Επιστήμης και Τεχνολογίας των Υλικών',
        'Μηχανικός Η/Υ, Τηλεπικοινωνιών και Δικτύων',
        'Μηχανικός Μεταλλείων',
        'Μηχανικός Ορυκτών Πόρων',
        'Μηχανικός Παραγωγής και Διοίκησης',
        'Μηχανικός Περιβάλλοντος',
        'Μηχανικός Πληροφοριακών και Επικοινωνιακών Συστημάτων',
        'Μηχανικός Πλοίων',
        'Μηχανικός Πολεμικής Αεροπορίας',
        'Μηχανικός Πολεμικού Ναυτικού',
        'Μηχανικός Τηλεπικοινωνιών',
        'Μηχανικός Χωροταξίας και Περιφερειακής Ανάπτυξης',
        'Μηχανοδηγός Τρένου',
        'Μηχανολόγος Μηχανικός',
        'Μηχανολόγος Μηχανικός Βιομηχανίας',
        'Μηχανολόγος Μηχανικός Συστημάτων Αυτόματου Ελέγχου και Ρομποτικής',
        'Μηχανοσυνθέτης Αεροσκαφών',
        'Μικροβιολόγος',
        'Μουσειολόγος Μουσειογράφος και Σχεδιαστής Εκθέσεων',
        'Μουσικολόγος',
        'Μουσικός',
        'Μουσικός Ενορχηστρωτής',
        'Μουσικός Επιμελητής',
        'Μόνιμος Υπαξιωματικός Αεροπορίας',
        'Μόνιμος Υπαξιωματικός Ναυτικού',
        'Μόνιμος Υπαξιωματικός Στρατού Ξηράς',
        'Νανοτεχνολόγος',
        'Ναυαγοσώστης',
        'Ναυπηγός Μηχανικός',
        'Ναύτης',
        'Νηπιαγωγός',
        'Νοσοκόμα Παίδων',
        'Νοσοκόμος-Νοσηλευτής',
        'Ντετέκτιβ',
        'Ξεναγός',
        'Ξενοδοχοϋπάλληλος',
        'Ξυλουργός',
        'Οδηγός Αυτοκινήτου Αγώνων',
        'Οδηγός Οχημάτων Δημοσίας Χρήσης',
        'Οδηγός ΤΑΞΙ',
        'Οδοντίατρος',
        'Οδοντοτεχνίτης',
        'Οικονομολόγος',
        'Οινολόγος',
        'Οπτικός',
        'Οργανοποιός',
        'Οργανωτής Συνεδρίων, Εκθέσεων και Εκδηλώσεων',
        'Οργανωτικός Συντονιστής Παραγωγής - Παραγωγός',
        'Οφθαλμίατρος',
        'Παιδίατρος',
        'Παραγωγός Κινηματογράφου και Τηλεόρασης',
        'Παραγωγός Προϊόντων Αλευρόμυλων, Παραγωγή Αμύλων και Προϊόντων Αμύλου',
        'Παραγωγός Ραδιοφωνικών Εκπομπών',
        'Πατωματζής (Επαγγέλματα Οικοδομής)',
        'Περιβαλλοντολόγος',
        'Πιλοποιός',
        'Πιλότος',
        'Πλέκτης',
        'Πλακάς',
        'Πλανόδιος Πωλητής',
        'Πλοίαρχος',
        'Πλοηγός Σκαφών Αναψυχής',
        'Πολιτικός Επιστήμονας',
        'Πολιτικός Μηχανικός',
        'Πολιτικός Συντάκτης',
        'Προγραμματιστής Συστημάτων και Εφαρμογών Η/Υ',
        'Προπονητής Αθλήματος',
        'Προπονητής Αντισφαίρισης',
        'Προπονητής Γυμναστικής με Βάρη',
        'Προπονητής Ελεύθερης Γυμναστικής',
        'Προπονητής Καλαθοσφαίρισης',
        'Προπονητής Κλασικού Αθλητισμού',
        'Προπονητής Κολύμβησης',
        'Προπονητής Πετοσφαίρισης',
        'Προπονητής Ποδοσφαίρου',
        'Πυροσβέστης',
        'Πωλητής',
        'Πωλητής Οικολογικών Τροφίμων και άλλων Ειδών',
        'Ράφτης',
        'Ρεσεψιονίστ Ξενοδοχείου',
        'Στέλεχος Υποδοχής Ξενοδοχείου',
        'Σεισμολόγος',
        'Σεναριογράφος',
        'Σερβιτόρος',
        'Σερβιτόρος Ποτών - Μπάρμαν',
        'Σιδεράς - Σιδηρουργός',
        'Σιδερωτής',
        'Σκηνογράφος',
        'Σκηνοθέτης Τηλεόρασης',
        'Σοβατζής',
        'Στέλεχος Marketing',
        'Στέλεχος Διεθνούς Εμπορίου',
        'Στέλεχος Εκδοτικών Επιχειρήσεων',
        'Στέλεχος Κοστολόγησης στη Βιομηχανία - Βιοτεχνία',
        'Στέλεχος Μικρομεσαίων Επιχειρήσεων',
        'Στέλεχος Τουρισμού',
        'Στέλεχος Τραπεζικών Εργασιών',
        'Στέλεχος Υπηρεσιών Ασφαλείας',
        'Στέλεχος Υπηρεσιών Εφοδιαστικής Αλυσίδας',
        'Στέλεχος Χρηματιστηριακών Εργασιών',
        'Στατιστικολόγος',
        'Στρατιωτικός Ψυχολόγος',
        'Στυλίστας',
        'Συμβολαιογράφος',
        'Συνοδός Εδάφους',
        'Συντηρητής Αρχαιοτήτων και Έργων Τέχνης',
        'Τεχνικός Συντήρησης Έργων Τέχνης',
        'Σφουγγαράς',
        'Σχεδιαστής Επίπλου',
        'Σχεδιαστής Κινουμένων Σχεδίων',
        'Σχεδιαστής Μέσω Συστημάτων Η/Υ',
        'Σχεδιαστής Πολυμέσων - Ειδικός Πολυμέσων',
        'Σχεδιαστής Υποδημάτων',
        'Σχολικός Σύμβουλος',
        'Σύμβουλος Επιχειρήσεων',
        'Σύμβουλος Σχολικού και Επαγγελματικού Προσανατολισμού',
        'Ταμίας',
        'Ταξιδιωτικός Συνοδός και Συνοδός δρυμών',
        'Τουριστικός Συνοδός',
        'Ταπετσέρης',
        'Ταπητουργός',
        'Ταχυδρόμος',
        'Χειριστής Τηλεφωνικού Κέντρου',
        'Τεχνίτης Αδαμαντοκοπής Μαρμάρων',
        'Τεχνίτης Αλιείας - Ιχθυοπαραγωγής - Τεχνολόγος Υδατοκαλλιεργητής',
        'Τεχνίτης Δερμάτινων Ειδών',
        'Τεχνίτης Φαρμάκων - Καλλυντικών - Τεχνικός Φαρμάκων Καλλυντικών και Παρεμφερών Προϊόντων',
        'Τεχνίτης Ψάθας - Καλαθοποιίας',
        'Τεχνίτης Ψηφιδωτών',
        'Τεχνικός - Ειδικός Εφαρμογών Πληροφορικής',
        'Τεχνικός Αερίων Καυσίμων',
        'Τεχνικός Αεροσκαφών - Ειδικός Μηχανοσύνθετων Αεροσκαφών',
        'Τεχνικός Αμπελουργίας - Οινοτεχνίας',
        'Τεχνικός Ανελκυστήρων',
        'Τεχνικός Αρδεύσεων',
        'Τεχνικός Αρτοποιίας - Ζαχαροπλαστικής',
        'Τεχνικός Ασφαλείας Δικτύων Η/Υ - Τεχνικός Δικτύων Υπολογιστών',
        'Τεχνικός Αυτοκινήτων Οχημάτων',
        'Τεχνικός Αυτοματισμών',
        'Τεχνικός Διαχείρισης Συστημάτων και Παροχής Υπηρεσιών Intranet - Internet',
        'Τεχνικός Διαχείρισης και Ανακύκλωσης Αποβλήτων',
        'Τεχνικός Δομικών Έργων',
        'Τεχνικός Ελέγχου Βιομηχανικού και Εργασιακού Περιβάλλοντος',
        'Τεχνικός Ελέγχου Ρύπανσης και Εγκαταστάσεων Αντιρρύπανσης',
        'Τεχνικός Ελέγχου Υλικών',
        'Τεχνικός Επεξεργασίας Γάλακτος',
        'Τεχνικός Εργαλειομηχανών',
        'Τεχνικός Εφαρμογών Ιατρικής Πληροφορικής',
        'Τεχνικός Εφαρμογών Πληροφορικής',
        'Τεχνικός Εφαρμογών Πληροφορικής, Δικτύων και Αυτοματισμού Γραφείου',
        'Τεχνικός Θέρμανσης και Υδραυλικών Εγκαταστάσεων',
        'Τεχνικός Κοσμήματος Παραγωγής',
        'Τεχνικός Μηχανών Θαλάσσης και Αναψυχής',
        'Τεχνικός Οργάνων Μετρήσεων',
        'Τεχνικός Ποτοποιίας - Αποσταγματοποιίας',
        'Τεχνικός Υπαξιωματικός Αεροπορίας',
        'Τεχνικός Ψηφιακής Φωτογραφίας και CD-ROM',
        'Τεχνολόγος - Δασοπόνος Διαχείρισης Φυσικών Πόρων',
        'Τεχνολόγος Ακτινολογίας Ακτινοθεραπείας',
        'Τεχνολόγος Αντιρρύπανσης',
        'Τεχνολόγος Βιομηχανικού Σχεδιασμού',
        'Τεχνολόγος Ενεργειακής Τεχνικής',
        'Τεχνολόγος Ιατρικών Οργάνων',
        'Τεχνολόγος Ιχθυοκαλλιέργειας',
        'Τεχνολόγος Ορυχείων',
        'Τεχνολόγος Πετρελαίου',
        'Τεχνολόγος Τηλεϊατρικής',
        'Τεχνολόγος Τροφίμων',
        'Τεχνολόγος Φυτικής Παραγωγής',
        'Τζακάς',
        'Τζαμάς',
        'Τηλεπαρουσιαστής',
        'Τηλεφωνητής',
        'Τουριστικός Πράκτορας',
        'Τραγουδιστής',
        'Τυπογράφος',
        'Υαλουργός',
        'Υδραυλικός',
        'Υλοτόμος',
        'Υπάλληλος Εξυπηρέτησης Πελατών',
        'Υπάλληλος Τουριστικού Γραφείου – Ειδικός Τουριστικού Πρακτορείου',
        'Υπάλληλος Τράπεζας',
        'Υπαξιωματικός Ενόπλων Δυνάμεων',
        'Υπεύθυνος Ανθρώπινου Δυναμικού',
        'Υπεύθυνος Γραφείου Τύπου',
        'Υπεύθυνος Δημοσίων Σχέσεων',
        'Υπεύθυνος Προμηθειών και Διαχείρισης Αποθήκης',
        'Φαρμακοποιός',
        'Φιλόλογος',
        'Φοντοποιός',
        'Φυσικός',
        'Φυσιοθεραπευτής',
        'Φωτογράφος - Τεχνικός Λήψης Φωτογραφίας - Έγχρωμη Φωτογραφία',
        'Φωτομοντέλο - Μανεκέν',
        'Φύλακας Ασφαλείας',
        'Φύλακας Μουσείων και Αρχαιολογικών Χώρων',
        'Χαράκτης',
        'Χειριστές Βαρέων Μηχανημάτων και Αγροτικών Μηχανημάτων',
        'Χειριστής Μηχανημάτων Κοπής Ξύλου',
        'Χειρούργος',
        'Χημικός',
        'Χημικός Μηχανικός',
        'Χορευτής',
        'Χορογράφος',
        'Χρηματιστής',
        'Χρηματοοικονομικός Σύμβουλος',
        'Χτίστης',
        'Ψαράς',
        'Ψυκτικός - Τεχνικός Εγκαταστάσεων Ψύξης Αερισμού και Κλιματισμού',
        'Ψυχίατρος',
        'Ψυχολόγος',
        'Ωκεανογράφος',
        'Ωρολογοποιός',
    ]
